@@ -1,5 +1,5 @@
 from collections.abc import Iterable
-from .attribute import _tpl_single_variable
+from .attribute import _tpl_attribute_function, _tpl_attribute_variable
 
 
 class _tpl_curve_data:
@@ -11,7 +11,7 @@ class _tpl_curve_data:
     self.y = y
     self.xerror = xerror
     self.yerror = yerror
-    self.label = _tpl_single_variable(value=label, token="addlegendentry", function_mode=True)
+    self.label = _tpl_attribute_function(token="addlegendentry", value=label)
     self.tablename = "table%d" % self.__class__.__counter
     self.__class__.__counter += 1
-    self.color = _tpl_single_variable(value=color, token="color")
+    self.color = _tpl_attribute_variable(token="color", value=color)
