@@ -1,4 +1,4 @@
-from collections.abc import Iterable
+from collections.abc import Iterable, Callable
 import csv
 import subprocess
 
@@ -35,7 +35,7 @@ class figure:
     self.__curves.append(_tpl_curve(x, y, xerror, yerror, label, color))
 
   def plotcsv(self, filename: str, xcolname: str, ycolname: str, xerrcolname: str = None, yerrcolname: str = None,
-              label: str = None, color: str = None):
+              label: str = None, color: str = None, yfunc: Callable = None):
     with open(filename, "r") as f:
       csvreader = csv.reader(f)
       data = dict()
@@ -61,6 +61,10 @@ class figure:
       xerr = data[xerrcolname] if xerrcolname in data.keys() else None
       yerr = data[yerrcolname] if yerrcolname in data.keys() else None
 
+      if yfunc is not None:
+        data[ycolname] = map(yfunc, data[ycolname])
+        yerr = map(yfunc, yerr)
+
       self.__curves.append(_tpl_curve(data[xcolname], data[ycolname], xerr, yerr, label, color))
 
   def savefig(self, filename: str):
@@ -107,6 +111,12 @@ class figure:
     self.__yticklabel._set_fixed(fixed)
     self.__yticklabel._set_zerofill(fixed)
 
+  def set_scaled_x_ticks(self, scaled_ticks: bool = True):
+    self.__xticklabel._set_scaled(scaled_ticks)
+
+  def set_scaled_y_ticks(self, scaled_ticks: bool = True):
+    self.__yticklabel._set_scaled(scaled_ticks)
+
   def set_legend_position(self, pos: str):
     self.__legend.pos.set_value(pos)
 
